@@ -73,22 +73,22 @@ fbolus1 <- function(InVVRefindex,
    Vm<-NULL
    Km<-NULL
    sub<-NULL
-   for( i in 1:length(unique(InVVRefindex$subject)))  {
+   for( i in 1:length(unique(InVVRefindex$subj)))  {
      cat("\n\n               << subject",i,">>\n\n" ) 
       sub[i]<-i  
      objfun <- function(par) {
         if (MMe) {
-           out <- modfun1(InVVRefindex$time[InVVRefindex$subject==i], par[1], par[2],par[3])
+           out <- modfun1(InVVRefindex$time[InVVRefindex$subj==i], par[1], par[2],par[3])
         } 
         else {
            ## No MM elimination
-           out <- modfun(InVVRefindex$time[InVVRefindex$subject==i], par[1], par[2])
+           out <- modfun(InVVRefindex$time[InVVRefindex$subj==i], par[1], par[2])
         }
-        gift <- which( InVVRefindex$concentration[InVVRefindex$subject==i] != 0 )
+        gift <- which( InVVRefindex$conc[InVVRefindex$subj==i] != 0 )
         switch(pick,
-             sum((InVVRefindex$concentration[InVVRefindex$subject==i][gift]-out[gift])^2),
-             sum((InVVRefindex$concentration[InVVRefindex$subject==i][gift]-out[gift])^2/InVVRefindex$concentration[gift]),
-             sum(((InVVRefindex$concentration[InVVRefindex$subject==i][gift]-out[gift])/InVVRefindex$concentration[gift])^2))
+             sum((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])^2),
+             sum((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])^2/InVVRefindex$conc[gift]),
+             sum(((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])/InVVRefindex$conc[gift])^2))
         }
 #The value of parameter obtained from genetic algorithm   
         if (MMe) {
@@ -141,7 +141,7 @@ fbolus1 <- function(InVVRefindex,
        ##Residuals sum-of-squares and parameter values fitted by nls
        cat("\n<< Residual sum-of-squares and parameter values fitted by nls >>\n\n")
        if (MMe) {
-         fm<-nls(concentration~modfun1(time,Vm,Km,Vd),data=InVVRefindex,subset=subject==i,
+         fm<-nls(conc~modfun1(time,Vm,Km,Vd),data=InVVRefindex,subset=subj==i,
                  start=list(Vm=opt$par[1],Km=opt$par[2],Vd=opt$par[3]),trace=TRUE,
                  nls.control(tol=1))
          cat("\n")
@@ -150,8 +150,8 @@ fbolus1 <- function(InVVRefindex,
        } 
        else {
         ## No MM elimination
-         fm<-nls(concentration ~ modfun(time, kel, Vd), data=InVVRefindex,
-                 start=list(kel=opt$par[1],Vd=opt$par[2]),trace=TRUE,subset=subject==i,
+         fm<-nls(conc ~ modfun(time, kel, Vd), data=InVVRefindex,
+                 start=list(kel=opt$par[1],Vd=opt$par[2]),trace=TRUE,subset=subj==i,
                  nls.control(tol=1))
          cat("\n")
          coef<-data.frame(coef(fm)["kel"])
@@ -160,7 +160,7 @@ fbolus1 <- function(InVVRefindex,
    }
  if (MMe) {
           cat("<< Summary >>\n")
-          keindex<-data.frame(subject=sub,Vm=Vm,Km=Km, Vd=Vd)
+          keindex<-data.frame(subj=sub,Vm=Vm,Km=Km, Vd=Vd)
           show(keindex)
               cat("\nSave data (y/n) ?\n")
             ans<-readline()
@@ -211,7 +211,7 @@ fbolus1 <- function(InVVRefindex,
     }   
        else {
           cat("<< Summary >>\n")
-          keindex<-data.frame(subject=sub,kel=ke,Vd=Vd)
+          keindex<-data.frame(subj=sub,kel=ke,Vd=Vd)
           show(keindex)   
             cat("\nSave data (y/n) ?\n")
             ans<-readline()
